pub struct RunQueueWithNext<'conf, 'r> {
pub current: &'r RunQueue<'conf>,
pub next: Option<&'r RunQueue<'conf>>,
}Expand description
A RunQueue paired with its optional successor RunQueue (the
queue where jobs go next)
Fields
current: &'r RunQueue<'conf>next: Option<&'r RunQueue<'conf>>Implementations
Sourceimpl<'conf, 'r> RunQueueWithNext<'conf, 'r>
impl<'conf, 'r> RunQueueWithNext<'conf, 'r>
Sourcepub fn run_job(
&self,
item: &QueueItem<'_, BenchmarkingJob>,
job_runner_with_job: &mut JobRunnerWithJob<'_, '_, '_, '_>,
erroneous_jobs_queue: Option<&RunQueue<'_>>,
done_jobs_queue: Option<&RunQueue<'_>>,
working_directory_id: WorkingDirectoryId,
) -> Result<JobStatus>
pub fn run_job( &self, item: &QueueItem<'_, BenchmarkingJob>, job_runner_with_job: &mut JobRunnerWithJob<'_, '_, '_, '_>, erroneous_jobs_queue: Option<&RunQueue<'_>>, done_jobs_queue: Option<&RunQueue<'_>>, working_directory_id: WorkingDirectoryId, ) -> Result<JobStatus>
Run the given job, which must be from this queue. item
represents the queue entry of this job, and is used for
locking and deletion–it must not already be locked!
Returns the status of the job after running it.
pub fn handle_timeout(&self) -> Result<()>